@@ -7,7 +7,7 @@ use Catmandu::Store::DBI::Bag;
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 with 'Catmandu::Store';
 with 'Catmandu::Transactional';
@@ -149,14 +149,30 @@ Version 0.0424
     # From the command line
     $ catmandu import JSON to DBI --data_source SQLite:mydb.sqlite < data.json
 
-    # From Perl code
+    # Or via a configuration file
+    $ cat catmandu.yml
+    ---
+    store:
+       mydb:
+         package: DBI
+         options:
+            data_source: "dbi:mysql:database=mydb"
+            username: xyz
+            password: xyz
+    ...
+    $ catmandu import JSON to mydb < data.json
+    $ catmandu export mydb to YAML > data.yml
+    $ catmandu export mydb --id 012E929E-FF44-11E6-B956-AE2804ED5190 to JSON > record.json
+    $ catmandu count mydb
+    $ catmandy delete mydb
 
-    use Catmandu;
+    # From perl
+    use Catmandu::Store::DBI;
 
-    my $store = Catmandu->store('DBI',
-        data_source => 'dbi:mysql:database=test',
-        username => 'foo', # optional
-        password => 'bar', # optional
+    my $store = Catmandu::Store::DBI->new(
+        data_source => 'DBI:mysql:database=mydb', # prefix "DBI:" optional
+        username => 'xyz', # optional
+        password => 'xyz', # optional
     );
 
     my $obj1 = $store->bag->add({ name => 'Patrick' });
