@@ -5,7 +5,7 @@ use Moo;
 use Catmandu::Store::DBI::Iterator;
 use namespace::clean;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 my $default_mapping = {
     _id => {
@@ -160,10 +160,10 @@ sub _data_to_row {
             $val = $self->serialize($val // next);
         }
         if ($map->{type} eq "datetime") {
-
-            chop($val);
-            $val = join(' ', split('T', $val));
-
+            # Translate ISO dates into datetime format
+            if ($val && $val =~ /^(\d{4}-\d{2}-\d{2})T(\d{2}:\d{2}:\d{2})/) {
+                $val = "$1 $2";
+            }
         }
         $row->{$map->{column}} = $val // next;
     }
@@ -372,4 +372,3 @@ The select statement of the source is between the parenthesises.
 =cut
 
 1;
-
