@@ -4,7 +4,7 @@ use Catmandu::Sane;
 use Moo;
 use namespace::clean;
 
-our $VERSION = "0.06";
+our $VERSION = "0.07";
 
 with 'Catmandu::Store::DBI::Handler';
 
@@ -27,6 +27,12 @@ sub _column_sql {
         $sql .= 'LONGBLOB';
     }
     elsif ($map->{type} eq 'datetime') {
+        $sql .= 'DATETIME';
+    }
+    elsif ($map->{type} eq 'datetime_milli') {
+        if ($dbh->{mysql_clientversion} < 50640)  {
+            Catmandu::NotImplemented->throw("DATETIME(3) only for MySQL > 5.6.4");
+        }
         $sql .= 'DATETIME(3)';
     }
     if ($map->{unique}) {
@@ -80,4 +86,3 @@ sub add_row {
 }
 
 1;
-
